@@ -8,27 +8,34 @@
 """Generic file writer and related tools"""
 
 import logging
+import sys
+from abc import ABCMeta, abstractmethod
+from six import add_metaclass
 
-from collections import Iterable
+
+if sys.version_info <= (3, 3):
+    from collections import Iterable
+else:
+    from collections.abc import Iterable
 
 import numpy
 
-try:
+from cclib.parser.utils import PeriodicTable
+from cclib.parser.utils import find_package
+
+_has_openbabel = find_package("openbabel")
+if _has_openbabel:
     from cclib.bridge import makeopenbabel
     import openbabel as ob
     import pybel as pb
-    _has_openbabel = True
-except ImportError:
-    _has_openbabel = False
-
-from cclib.parser.utils import PeriodicTable
 
 
 class MissingAttributeError(Exception):
     pass
 
 
-class Writer(object):
+@add_metaclass(ABCMeta)
+class Writer:
     """Abstract class for writer objects."""
 
     required_attrs = ()
@@ -50,6 +57,7 @@ class Writer(object):
         self.jobfilename = jobfilename
         self.indices = indices
         self.terse = terse
+        self.ghost = kwargs.get("ghost")
 
         self.pt = PeriodicTable()
 
@@ -64,14 +72,9 @@ class Writer(object):
 
         self._fix_indices()
 
+    @abstractmethod
     def generate_repr(self):
-        """Generate the written representation of the logfile data.
-
-        This should be overriden by all the subclasses inheriting from
-        Writer.
-        """
-        raise NotImplementedError(
-            'generate_repr is not implemented for ' + str(type(self)))
+        """Generate the written representation of the logfile data."""
 
     def _calculate_total_dipole_moment(self):
         """Calculate the total dipole moment."""
@@ -90,7 +93,7 @@ class Writer(object):
                 'Could not parse required attributes to write file: ' + missing)
 
     def _make_openbabel_from_ccdata(self):
-        """Create Open Babel and Pybel molecules from ccData."""        
+        """Create Open Babel and Pybel molecules from ccData."""
         if not hasattr(self.ccdata, 'charge'):
             logging.warning("ccdata object does not have charge, setting to 0")
             _charge = 0
@@ -142,3 +145,6 @@ class Writer(object):
                 indices.add(i)
             self.indices = indices
         return
+
+
+del find_package
