@@ -81,11 +81,34 @@ class DALTON(logfileparser.Logfile):
 
         # Extract the version number and optionally the Git revision
         # number.
+        #
+        # Example strings that at least the major version is parsed from:
+        #                            
+        # This is output from DALTON 2013.2
+        #                            2013.4
+        #                            2014.0
+        #                            2014.alpha
+        #                            2015.0
+        #                            2016.alpha
+        #                            (Release 1.1, September 2000)
+        #                            Release 2011 (DEVELOPMENT VERSION)
+        #                            Release 2011 (Rev. 0, Dec. 2010)
+        #                            Release 2011 (Rev. 0, Mar. 2011)
+        #                            (Release 2.0 rev. 0, Mar. 2005)
+        #                            (Release Dalton2013 patch 0)
+        #                            release Dalton2017.alpha (2016)
+        #                            release Dalton2017.alpha (2017)
+        #                            release Dalton2018.0 (2018)
+        #                            release Dalton2018.0-rc (2018)
+        #                            release Dalton2018.alpha (2018)
+        #                            release Dalton2019.alpha (2018)
         if line[4:30] == "This is output from DALTON":
-            rs = r"([0-9]{4})\D\s?\w*\s?([0-9]{1})"
+            rs = (r"from DALTON \(?(?:Release|release)?\s?(?:Dalton)?"
+                  r"(\d+\.?[\w\d\-]*)"
+                  r"(?:[\s,]\(?)?")
             match = re.search(rs, line)
-            package_version = ".".join(match.groups())
-            self.metadata["package_version"] = package_version
+            if match:
+                self.metadata["package_version"] = match.groups()[0]
         # Don't add revision information to the main package version for now.
         if "Last Git revision" in line:
             revision = line.split()[4]
@@ -1094,6 +1117,9 @@ class DALTON(logfileparser.Logfile):
                 polarizability.append(line.split()[1:])
             self.polarizabilities.append(numpy.array(polarizability))
 
+        if "Starting in Dynamic Property Section (RESPONS)" in line:
+            self.section = "RESPONSE"
+
         # Static and dynamic polarizability from **RESPONSE/*LINEAR.
         # This section is *very* general and will need to be expanded later.
         # For now, only form the matrix from dipole (length gauge) values.
@@ -1119,14 +1145,40 @@ class DALTON(logfileparser.Logfile):
             if hasattr(self, 'polarizabilities'):
                 self.polarizabilities.append(polarizability_diplen)
 
-        # Electronic excitations: single residues of the linear
-        # response equations.
+        ## Electronic excitations: single residues of the linear response
+        ## equations.
+        #
+        #
+        #  @ Excited state no:    1 in symmetry 3  ( Bu )
+        #  ----------------------------------------------
+        #
+        # @ Excitation energy :  0.19609400     au
+        # @                      5.3359892     eV;   43037.658     cm-1;   514.84472     kJ / mol
+        #
+        # @ Total energy :      -381.85462     au
+        #
+        # @ Operator type:    XDIPLEN 
+        # @ Oscillator strength (LENGTH)   :  8.93558787E-03  (Transition moment :  0.26144181     )
+        #
+        # @ Operator type:    YDIPLEN 
+        # @ Oscillator strength (LENGTH)   :  0.15204812      (Transition moment :   1.0784599     )
+        #
+        #  Eigenvector for state no.  1
+        #
+        #      Response orbital operator symmetry = 3
+        #      (only scaled elements abs greater than   10.00 % of max abs value)
+        #
+        #       Index(r,s)      r      s        (r s) operator      (s r) operator      (r s) scaled        (s r) scaled
+        #       ----------    -----  -----      --------------      --------------      --------------      --------------
+        #          308        57(4)  28(2)        0.4829593728       -0.0024872024        0.6830076950       -0.0035174354
+        #          ...
         if "Linear Response single residue calculation" in line:
 
             etsyms = []
             etenergies = []
-            # etoscs = []
             etsecs = []
+            etoscs = dict()
+            etoscs_keys = set()
 
             symmap = {"T": "Triplet", "F": "Singlet"}
 
@@ -1137,48 +1189,73 @@ class DALTON(logfileparser.Logfile):
                 if "Operator symmetry" in line:
                     do_triplet = line[-2]
 
-                if "@ Excited state no:" in line:
-                    etsym = line.split()[9] # -2
+                # @ Excited state no:    4 in symmetry 2  ( Au )
+                if line.startswith(" @ Excited state no:"):
+                    tokens = line.split()
+                    excited_state_num_in_sym = int(tokens[4])
+                    sym_num = int(tokens[7])
+                    etosc_key = (sym_num, excited_state_num_in_sym)
+                    etoscs_keys.add(etosc_key)
+                    etsym = tokens[9]
                     etsyms.append(symmap[do_triplet] + "-" + etsym)
-                    self.skip_lines(inputfile, ['d', 'b', 'Excitation energy in a.u.'])
+                    self.skip_lines(inputfile, ["d", "b", "Excitation energy in a.u."])
                     line = next(inputfile)
-                    etenergy = float(line.split()[1])
-                    etenergies.append(etenergy)
+                    etenergies.append(self.float(line.split()[3]))
+                    self.skip_lines(inputfile, ["b", "@ Total energy", "b"])
 
-                    while "The dominant contributions" not in line:
-                        line = next(inputfile)
-
-                    self.skip_line(inputfile, 'b')
+                if line.startswith("@ Operator type:"):
                     line = next(inputfile)
-                    # [0] is the starting (occupied) MO
-                    # [1] is the ending (unoccupied) MO
-                    # [2] and [3] are the excitation/deexcitation coefficients
-                    # [4] is the orbital overlap
-                    # [5] is the ...
-                    # [6] is the ...
-                    # [7] is the ...
-                    assert "I    A    K_IA      K_AI   <|I|*|A|> <I^2*A^2>    Weight   Contrib" in line
-                    self.skip_line(inputfile, 'b')
-                    line = next(inputfile)
-                    sec = []
+                    assert line.startswith("@ Oscillator strength")
+                    if etosc_key not in etoscs:
+                        etoscs[etosc_key] = 0.0
+                    etoscs[etosc_key] += self.float(line.split()[5])
+                    self.skip_line(inputfile, "b")
 
+                # To understand why the "PBHT MO Overlap Diagnostic" section
+                # cannot be used, see
+                # `test/regression.py/testDALTON_DALTON_2013_dvb_td_normalprint_out`.
+                if "Eigenvector for state no." in line:
+                    assert int(line.split()[4]) == excited_state_num_in_sym
+                    self.skip_lines(inputfile, [
+                        "b",
+                        "Response orbital operator symmetry",
+                        "only scaled elements",
+                        "b",
+                        "Index(r,s)",
+                        "d"
+                    ])
+                    line = next(inputfile)
+                    etsec = []
                     while line.strip():
-                        chomp = line.split()
-                        startidx = int(chomp[0]) - 1
-                        endidx = int(chomp[1]) - 1
-                        contrib = float(chomp[2])
-                        # Since DALTON is restricted open-shell only,
-                        # there is not distinction between alpha and
-                        # beta spin.
-                        sec.append([(startidx, 0), (endidx, 0), contrib])
+                        tokens = line.split()
+                        startidx = int(tokens[1].split("(")[0]) - 1
+                        endidx = int(tokens[2].split("(")[0]) - 1
+                        # `(r s) scaled`; to handle anything other than
+                        # CIS/TDA properly, the deexcitation coefficient `(s
+                        # r) scaled` should also be considered, but this
+                        # requires a rework of the attribute structure.
+                        contrib = float(tokens[5])
+                        # Since DALTON is restricted open-shell only, there is
+                        # no distinction between alpha and beta spin.
+                        etsec.append([(startidx, 0), (endidx, 0), contrib])
                         line = next(inputfile)
+                    etsecs.append(etsec)
 
-                    etsecs.append(sec)
-
-            self.set_attribute('etsyms', etsyms)
-            self.set_attribute('etenergies', etenergies)
-            # self.set_attribute('etoscs', etoscs)
-            self.set_attribute('etsecs', etsecs)
+            self.set_attribute("etsyms", etsyms)
+            self.set_attribute("etenergies", etenergies)
+            if etsecs:
+                self.set_attribute("etsecs", etsecs)
+            if etoscs:
+                for k in etoscs_keys:
+                    # If the oscillator strength of a transition is known to
+                    # be zero for symmetry reasons, it isn't printed, however
+                    # we need it for consistency; if it wasn't found, add it.
+                    if k not in etoscs:
+                        etoscs[k] = 0.0
+                # `.keys()` is not strictly necessary, but make it obvious
+                # that this is being sorted in order of excitation and
+                # symmetry, not oscillator strength.
+                self.set_attribute("etoscs", [etoscs[k] for k in sorted(etoscs.keys())])
 
         if line[:37] == ' >>>> Total wall time used in DALTON:':
             self.metadata['success'] = True
@@ -1191,7 +1268,6 @@ class DALTON(logfileparser.Logfile):
         # coreelectrons
         # enthalpy
         # entropy
-        # etoscs
         # etrotats
         # freeenergy
         # grads
