@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2019, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -108,6 +108,7 @@ class ORCA(logfileparser.Logfile):
             self.skip_line(inputfile, '=')
             self.metadata['input_file_name'] = next(inputfile).split()[-1]
 
+            # First, collect all the lines...
             lines = []
             for line in inputfile:
                 if line[0] != '|':
@@ -119,6 +120,7 @@ class ORCA(logfileparser.Logfile):
 
             keywords = []
             coords = []
+            # ...then parse them separately.
             for line in lines_iter:
                 line = line.strip()
                 if not line:
@@ -169,7 +171,9 @@ class ORCA(logfileparser.Logfile):
                         for line in lines_iter:
                             if not line:
                                 continue
-                            if line[0] == '*' or "end" in line:
+                            if line[0] == '#' or line.strip(' ') == '\n':
+                                continue
+                            if line[0] == '*' or line.strip() == "end":
                                 break
                             # Strip basis specification that can appear after coordinates
                             line = line.split('newGTO')[0].strip()
@@ -410,9 +414,6 @@ class ORCA(logfileparser.Logfile):
         #
         if line[33:53] == "Geometry convergence":
 
-            if not hasattr(self, "geovalues"):
-                self.geovalues = []
-
             headers = next(inputfile)
             dashes = next(inputfile)
 
@@ -420,10 +421,12 @@ class ORCA(logfileparser.Logfile):
             values = []
             targets = []
             line = next(inputfile)
-            while list(set(line.strip())) != ["."]:
+            # Handle both the dots only and dashes only cases
+            while len(list(set(line.strip()))) != 1:
                 name = line[10:28].strip().lower()
-                value = float(line.split()[2])
-                target = float(line.split()[3])
+                tokens = line.split()
+                value = float(tokens[2])
+                target = float(tokens[3])
                 names.append(name)
                 values.append(value)
                 targets.append(target)
@@ -445,7 +448,7 @@ class ORCA(logfileparser.Logfile):
                     newvalues.append(values[names.index(n)])
                     assert targets[names.index(n)] == self.geotargets[i]
 
-            self.geovalues.append(newvalues)
+            self.append_attribute("geovalues", newvalues)
 
         """ Grab cartesian coordinates
         ---------------------------------
@@ -463,15 +466,14 @@ class ORCA(logfileparser.Logfile):
             line = next(inputfile)
             while len(line) > 1:
                 atom, x, y, z = line.split()
-                atomnos.append(self.table.number[atom])
-                atomcoords.append([float(x), float(y), float(z)])
+                if atom[-1] != ">":
+                    atomnos.append(self.table.number[atom])
+                    atomcoords.append([float(x), float(y), float(z)])
                 line = next(inputfile)
 
             self.set_attribute('natom', len(atomnos))
             self.set_attribute('atomnos', atomnos)
-            if not hasattr(self, 'atomcoords'):
-                self.atomcoords = []
-            self.atomcoords.append(atomcoords)
+            self.append_attribute("atomcoords", atomcoords)
 
         """ Grab atom masses
         ----------------------------
@@ -491,8 +493,11 @@ class ORCA(logfileparser.Logfile):
             while len(line) > 1:
                 if line[:32] == '* core charge reduced due to ECP':
                     break
+                if line.strip() == "> coreless ECP center with (optional) point charge":
+                    break
                 no, lb, za, frag, mass, x, y, z = line.split()
-                self.atommasses.append(float(mass))
+                if lb[-1] != ">":
+                    self.atommasses.append(float(mass))
                 line = next(inputfile)
 
         if line[21:68] == "FINAL ENERGY EVALUATION AT THE STATIONARY POINT":
@@ -761,10 +766,9 @@ class ORCA(logfileparser.Logfile):
             else:
                 sym = "Not specified"
 
-            if not hasattr(self, "etenergies"):
-                self.etsecs = []
-                self.etenergies = []
-                self.etsyms = []
+            etsecs = []
+            etenergies = []
+            etsyms = []
 
             lookup = {'a': 0, 'b': 1}
             line = next(inputfile)
@@ -773,8 +777,8 @@ class ORCA(logfileparser.Logfile):
             # Contains STATE or is blank
             while line.find("STATE") >= 0:
                 broken = line.split()
-                self.etenergies.append(float(broken[-2]))
-                self.etsyms.append(sym)
+                etenergies.append(float(broken[-2]))
+                etsyms.append(sym)
                 line = next(inputfile)
                 sec = []
                 # Contains SEC or is blank
@@ -792,9 +796,13 @@ class ORCA(logfileparser.Logfile):
                         contrib = numpy.nan
                     sec.append([start, end, contrib])
                     line = next(inputfile)
-                self.etsecs.append(sec)
+                etsecs.append(sec)
                 line = next(inputfile)
 
+            self.extend_attribute('etenergies', etenergies)
+            self.extend_attribute('etsecs', etsecs)
+            self.extend_attribute('etsyms', etsyms)
+
         # Parse the various absorption spectra for TDDFT and ROCIS.
         if 'ABSORPTION SPECTRUM' in line or 'ELECTRIC DIPOLE' in line:
             # CASSCF has an anomalous printing of ABSORPTION SPECTRUM.
@@ -905,7 +913,8 @@ States    Energy  Wavelength   fosc         T2         TX        TY        TZ
                     state, state2, energy, wavelength, intensity, t2, tx, ty, tz = line.split()
                     return energy, intensity
 
-            elif line[:79] == 'ROCIS COMBINED ELECTRIC DIPOLE + MAGNETIC DIPOLE + ELECTRIC QUADRUPOLE SPECTRUM':
+            elif line[:79] == 'ROCIS COMBINED ELECTRIC DIPOLE + MAGNETIC DIPOLE + ELECTRIC QUADRUPOLE SPECTRUM' \
+                 or line[:87] == 'SOC CORRECTED COMBINED ELECTRIC DIPOLE + MAGNETIC DIPOLE + ELECTRIC QUADRUPOLE SPECTRUM':
                 def energy_intensity(line):
                     """ ROCIS with DoQuad = True and SOC = True (also does origin adjusted)
 ------------------------------------------------------------------------------------------------------
@@ -955,9 +964,9 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
 
                 line = next(inputfile)
 
-            self.etenergies = numpy.array(etenergies)
-            self.etoscs = numpy.array(etoscs)
-            self.transprop[name] = (self.etenergies, self.etoscs)
+            self.set_attribute('etenergies', etenergies)
+            self.set_attribute('etoscs', etoscs)
+            self.transprop[name] = (numpy.asarray(etenergies), numpy.asarray(etoscs))
 
         if line.strip() == "CD SPECTRUM":
             # -------------------------------------------------------------------
@@ -990,6 +999,10 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
         if line[:23] == "VIBRATIONAL FREQUENCIES":
             self.skip_lines(inputfile, ['d', 'b'])
 
+            # Starting with 4.1, a scaling factor for frequencies is printed
+            if float(self.metadata["package_version"][:3]) > 4.0:
+                self.skip_lines(inputfile, ['Scaling factor for frequencies', 'b'])
+
             vibfreqs = numpy.zeros(3 * self.natom)
             for i, line in zip(range(3 * self.natom), inputfile):
                 vibfreqs[i] = float(line.split()[1])
@@ -1003,7 +1016,7 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
                 msg = "Modes corresponding to rotations/translations may be non-zero."
                 if self.num_modes == 3*self.natom - 5:
                     msg += '\n You can ignore this if the molecule is linear.'
-            self.vibfreqs = vibfreqs[self.first_mode:]
+            self.set_attribute('vibfreqs', vibfreqs[self.first_mode:])
 
         # NORMAL MODES
         # ------------
@@ -1018,18 +1031,18 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
         #       2       0.000000   0.000000   0.000000   0.000000   0.000000   0.000000
         # ...
         if line[:12] == "NORMAL MODES":
-            vibdisps = numpy.zeros((3 * self.natom, self.natom, 3), "d")
+            all_vibdisps = numpy.zeros((3 * self.natom, self.natom, 3), "d")
 
             self.skip_lines(inputfile, ['d', 'b', 'text', 'text', 'text', 'b'])
 
             for mode in range(0, 3 * self.natom, 6):
                 header = next(inputfile)
                 for atom in range(self.natom):
-                    vibdisps[mode:mode + 6, atom, 0] = next(inputfile).split()[1:]
-                    vibdisps[mode:mode + 6, atom, 1] = next(inputfile).split()[1:]
-                    vibdisps[mode:mode + 6, atom, 2] = next(inputfile).split()[1:]
+                    all_vibdisps[mode:mode + 6, atom, 0] = next(inputfile).split()[1:]
+                    all_vibdisps[mode:mode + 6, atom, 1] = next(inputfile).split()[1:]
+                    all_vibdisps[mode:mode + 6, atom, 2] = next(inputfile).split()[1:]
 
-            self.vibdisps = vibdisps[self.first_mode:]
+            self.set_attribute('vibdisps', all_vibdisps[self.first_mode:])
 
         # -----------
         # IR SPECTRUM
@@ -1043,15 +1056,15 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
         if line[:11] == "IR SPECTRUM":
             self.skip_lines(inputfile, ['d', 'b', 'header', 'd'])
 
-            self.vibirs = numpy.zeros((3 * self.natom,), "d")
+            all_vibirs = numpy.zeros((3 * self.natom,), "d")
 
             line = next(inputfile)
             while len(line) > 2:
                 num = int(line[0:4])
-                self.vibirs[num] = float(line.split()[2])
+                all_vibirs[num] = float(line.split()[2])
                 line = next(inputfile)
 
-            self.vibirs = self.vibirs[self.first_mode:]
+            self.set_attribute('vibirs', all_vibirs[self.first_mode:])
 
         # --------------
         # RAMAN SPECTRUM
@@ -1065,15 +1078,15 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
         if line[:14] == "RAMAN SPECTRUM":
             self.skip_lines(inputfile, ['d', 'b', 'header', 'd'])
 
-            self.vibramans = numpy.zeros(3 * self.natom)
+            all_vibramans = numpy.zeros(3 * self.natom)
 
             line = next(inputfile)
             while len(line) > 2:
                 num = int(line[0:4])
-                self.vibramans[num] = float(line.split()[2])
+                all_vibramans[num] = float(line.split()[2])
                 line = next(inputfile)
 
-            self.vibramans = self.vibramans[self.first_mode:]
+            self.set_attribute('vibramans', all_vibramans[self.first_mode:])
 
 
         # ORCA will print atomic charges along with the spin populations,
@@ -1136,13 +1149,13 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             dipole = utils.convertor(dipole, "ebohr", "Debye")
 
             if not hasattr(self, 'moments'):
-                self.moments = [reference, dipole]
+                self.set_attribute('moments', [reference, dipole])
             else:
                 try:
                     assert numpy.all(self.moments[1] == dipole)
                 except AssertionError:
                     self.logger.warning('Overwriting previous multipole moments with new values')
-                    self.moments = [reference, dipole]
+                    self.set_attribute('moments', [reference, dipole])
 
         if "Molecular Dynamics Iteration" in line:
             self.skip_lines(inputfile, ['d', 'ORCA MD', 'd', 'New Coordinates'])
@@ -1462,9 +1475,11 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
 
         line = next(inputfile)
         while not should_stop(line):
-            charges.append(float(line[start:stop]))
-            if has_spins:
-                spins.append(float(line[stop:]))
+            # Don't add point charges or embedding potentials.
+            if "Q :" not in line:
+                charges.append(float(line[start:stop]))
+                if has_spins:
+                    spins.append(float(line[stop:]))
             line = next(inputfile)
 
         self.atomcharges[chargestype] = charges
