@@ -25,29 +25,41 @@ class MOLDENTest(unittest.TestCase):
     def test_missing_attribute_error(self):
         """Check if MissingAttributeError is raised as expected."""
         fpath = os.path.join(__datadir__,
-                             "data/GAMESS/basicGAMESS-US2014/dvb_un_sp.out")
+                             "data/GAMESS/basicGAMESS-US2018/dvb_un_sp.out")
         required_attrs = ['atomcoords', 'atomnos', 'natom']
         for attr in required_attrs:
             data = cclib.io.ccread(fpath)
             delattr(data, attr)
 
-            # Molden files cannot be wriiten if required attrs are missing.
+            # Molden files cannot be written if required attrs are missing.
             with self.assertRaises(MissingAttributeError):
                 cclib.io.moldenwriter.MOLDEN(data)
 
     def test_atoms_section_size(self):
         """Check if size of Atoms section is equal to expected."""
         fpath = os.path.join(__datadir__,
-                             "data/GAMESS/basicGAMESS-US2014/dvb_un_sp.out")
+                             "data/GAMESS/basicGAMESS-US2018/dvb_un_sp.out")
         data = cclib.io.ccread(fpath)
         writer = cclib.io.moldenwriter.MOLDEN(data)
         # Check size of Atoms section.
         self.assertEqual(len(writer._coords_from_ccdata(-1)), data.natom)
 
+    def test_atoms_section_size_with_ghost(self):
+        """Check if size of Atoms section is equal to expected with a ghost atom present."""
+        fpath = os.path.join(__datadir__,
+                             "data/GAMESS/basicGAMESS-US2018/dvb_un_sp_ghost.out")
+        data = cclib.io.ccread(fpath)
+        writer = cclib.io.moldenwriter.MOLDEN(data)
+        writer.ghost = "GH"
+        # Check for the ghost atom, and make sure it has the right label.
+        self.assertIn("GH", writer._coords_from_ccdata(-1)[0])
+        # Check size of Atoms section.
+        self.assertEqual(len(writer._coords_from_ccdata(-1)), data.natom)
+
     def test_gto_section_size(self):
         """Check if size of GTO section is equal to expected."""
         fpath = os.path.join(__datadir__,
-                             "data/GAMESS/basicGAMESS-US2014/dvb_un_sp.out")
+                             "data/GAMESS/basicGAMESS-US2018/dvb_un_sp.out")
         data = cclib.io.ccread(fpath)
         writer = cclib.io.moldenwriter.MOLDEN(data)
         # Check size of GTO section.
@@ -63,7 +75,7 @@ class MOLDENTest(unittest.TestCase):
     def test_mo_section_size(self):
         """Check if size of MO section is equal to expected."""
         fpath = os.path.join(__datadir__,
-                             "data/GAMESS/basicGAMESS-US2014/dvb_un_sp.out")
+                             "data/GAMESS/basicGAMESS-US2018/dvb_un_sp.out")
         data = cclib.io.ccread(fpath)
         writer = cclib.io.moldenwriter.MOLDEN(data)
         # Check size of MO section.
@@ -96,7 +108,7 @@ class MOLDENTest(unittest.TestCase):
         filenames = ['dvb_un_sp', 'C_bigbasis', 'water_mp2']
         for fn in filenames:
             fpath = os.path.join(__datadir__,
-                                 "data/GAMESS/basicGAMESS-US2014/"+fn+".out")
+                                 "data/GAMESS/basicGAMESS-US2018/"+fn+".out")
             data = cclib.io.ccread(fpath)
             cclib_out = cclib.io.moldenwriter.MOLDEN(data).generate_repr()
             # Reformat cclib's output to remove extra spaces.
