@@ -28,10 +28,14 @@ sys.path.insert(1, os.path.join(__filedir__, 'data'))
 
 parser_names = [
     "ADF", "DALTON", "GAMESS", "GAMESSUK", "Gaussian", "Jaguar", "Molpro",
-    "Molcas", "MOPAC", "NWChem", "ORCA", "Psi3", "Psi4", "QChem", "Turbomole",
+    "Molcas", "MOPAC", "NWChem", "ORCA", "Psi4", "QChem", "Turbomole",
 ]
 all_parsers = {name: getattr(cclib.parser, name) for name in parser_names}
 
+# Not used currently, but keeping in a list to keep track of which parsers
+# are in the legacy bin.
+legacy_parser_names = ["Psi3"]
+
 
 module_names = [
     "SP", "SPun", "GeoOpt", "Basis", "Core",    # Basic calculations.
@@ -74,7 +78,7 @@ def get_program_dir(parser_name):
     return parser_name
 
 
-def getdatafile(parser, subdir, files, stream=None, loglevel=0, datatype=None):
+def getdatafile(parser, subdir, files, stream=None, loglevel=logging.ERROR, datatype=None):
     """Returns a parsed logfile.
 
     Inputs:
@@ -104,9 +108,8 @@ def getdatafile(parser, subdir, files, stream=None, loglevel=0, datatype=None):
         inputs = inputs[0]
 
     stream = stream or sys.stdout
-    logfile = parser(inputs, logstream=stream,
+    logfile = parser(inputs, logstream=stream, loglevel=loglevel,
                      datatype=datatype or cclib.parser.data.ccData)
-    logfile.logger.setLevel(loglevel)
 
     data = logfile.parse()
     return data, logfile
@@ -129,12 +132,13 @@ class DataSuite(object):
     subdirectory, and do some basic bookkeeping.
     """
 
-    def __init__(self, parsers, modules, terse=False, silent=False, stream=sys.stdout):
+    def __init__(self, parsers, modules, terse=False, silent=False, loglevel=logging.ERROR, stream=sys.stdout):
 
         self.parsers = parsers
         self.modules = modules
         self.terse = terse or silent
         self.silent = silent
+        self.loglevel = loglevel
         self.stream = stream
 
         # Load the test data and filter with parsers and modules.
@@ -173,9 +177,10 @@ class DataSuite(object):
                 description = "%s/%s: %s" % (td['subdir'], ",".join(td['files']), test.__doc__)
                 print("*** %s ***" % description, file=self.stream)
 
-            loglevel = 33 if self.silent else 0
-            test.data, test.logfile = getdatafile(parser, td['subdir'], td['files'], stream=self.stream, loglevel=loglevel,
-                                                  datatype=test.datatype if hasattr(test, 'datatype') else None)
+            test.data, test.logfile = getdatafile(
+                parser, td['subdir'], td['files'], stream=self.stream, loglevel=self.loglevel,
+                datatype=test.datatype if hasattr(test, 'datatype') else None
+            )
 
             # By overriding __getattribute__ temporarily with a custom method, we collect
             # coverage information for data attributes while the tests are run. This slightly
@@ -203,6 +208,8 @@ class DataSuite(object):
         if self.terse:
             devnull.close()
 
+        return self.errors or self.failures
+
     def summary(self):
         """Prints a summary of the suite after it has been run."""
 
@@ -231,9 +238,6 @@ class DataSuite(object):
         print("TOTAL: %d\tPASSED: %d\tFAILED: %d\tERRORS: %d\tSKIPPED: %d" \
                 %(total[0], total[0]-(total[1]+total[2]+total[3]), total[2], total[1], total[3]), file=self.stream)
 
-        if self.errors or self.failures:
-            sys.exit(1)
-
     def visualtests(self, stream=sys.stdout):
         """These are not formal tests -- but they should be eyeballed."""
 
@@ -248,7 +252,7 @@ class DataSuite(object):
             # Note that it doesn't make sense to put MOPAC here, as it
             # is a semiempirical-only program.
             'NWChem6.5' : getdatafile('NWChem', "basicNWChem6.5", ["dvb_gopt_ks.out"])[0],
-            'ORCA4.0' : getdatafile('ORCA', "basicORCA4.0", ["dvb_gopt.out"])[0],
+            'ORCA4.1' : getdatafile('ORCA', "basicORCA4.1", ["dvb_gopt.out"])[0],
             'Psi4-1.0' : getdatafile('Psi4', "basicPsi4-1.0", ["dvb_gopt_rks.out"])[0],
             'QChem5.1' : getdatafile('QChem', "basicQChem5.1", ["dvb_gopt.out"])[0],
         }
@@ -263,31 +267,43 @@ class DataSuite(object):
         print("H-L ", "   ".join(["%9.4f" % (out.moenergies[0][out.homos[0]+1]-out.moenergies[0][out.homos[0]],) for out in output]), file=self.stream)
 
 
-def test_all(parsers=None, modules=None, terse=False, silent=True, summary=True, visual_tests=True):
+def test_all(parsers, modules, terse, silent, loglevel, summary, visual_tests):
     parsers = parsers or all_parsers
     modules = modules or all_modules
-    data_suite = DataSuite(parsers, modules, terse=terse, silent=silent)
-    data_suite.testall()
+    data_suite = DataSuite(parsers, modules, terse=terse, silent=silent, loglevel=loglevel)
+    errors_or_failures = data_suite.testall()
     if summary and not silent:
         data_suite.summary()
     if visual_tests and not silent:
         data_suite.visualtests()
+    if errors_or_failures:
+        sys.exit(1)
 
 
 if __name__ == "__main__":
 
-    if "--debug" in sys.argv:
-        logging.getLogger().setLevel(logging.DEBUG)
-    else:
-        logging.getLogger().setLevel(logging.ERROR)
+    import argparse
 
-    # These allow the parsers and modules tested to be filtered on the command line
-    # with any number of arguments. No matching parsers/modules implies all of them.
-    parsers = {p: all_parsers[p] for p in parser_names if p in sys.argv} or None
-    modules = {m: all_modules[m] for m in module_names if m in sys.argv} or None
+    parser = argparse.ArgumentParser()
 
-    # These options modify the output and are used by testall and Travis CI.
-    terse = "--terse" in sys.argv
-    silent = "--silent" in sys.argv
+    parser.add_argument("--debug", action="store_true")
+    parser.add_argument("--terse", action="store_true")
+    parser.add_argument("--silent", action="store_true")
+    parser.add_argument(
+        "parser_or_module",
+        nargs="*",
+        help="Limit the test to the packages/parsers passed as arguments. "
+             "No arguments implies all parsers."
+    )
 
-    test_all(parsers, modules, terse=terse, silent=silent)
+    args = parser.parse_args()
+
+    loglevel = logging.DEBUG if args.debug else logging.ERROR
+
+    # No matching parsers/modules implies all of them.
+    parsers = {p: all_parsers[p] for p in parser_names
+               if p in args.parser_or_module} or None
+    modules = {m: all_modules[m] for m in module_names
+               if m in args.parser_or_module} or None
+
+    test_all(parsers, modules, terse=args.terse, silent=args.silent, loglevel=loglevel, summary=True, visual_tests=True)
